## `bycon/services/config` directory

This directory contains the eponymously named configuration files for the
`services` apps, as `.yaml` files.

Depending on the service, these (usually) provide information additionally to
the root `bycon/config` environment configurations, e.g. about the read-in
libraries or output formats and options specific for the service.
